<?php
global $global_class_map;
$global_class_map = array(
	'AccrualBalanceFactory' => 'accrual/AccrualBalanceFactory.class.php',
	'AccrualBalanceListFactory' => 'accrual/AccrualBalanceListFactory.class.php',
	'AccrualFactory' => 'accrual/AccrualFactory.class.php',
	'AccrualListFactory' => 'accrual/AccrualListFactory.class.php',
	'DiscoveryService' => 'api/amfphp/DiscoveryService.class.php',
	'TimeTrexClientAPI' => 'api/client/TimeTrexClientAPI.class.php',
    'APIEnvironment' => 'api/core/APIEnvironment.class.php',
    'APILog' => 'api/core/APILog.class.php',
    'APILogDetail' => 'api/core/APILogDetail.class.php',
	'APIBranch' => 'api/company/APIBranch.class.php',
	'APICompany' => 'api/company/APICompany.class.php',
    'APICompanyGenericTag' => 'api/company/APICompanyGenericTag.class.php',
    'APIOtherField' => 'api/core/APIOtherField.class.php',
	'APIWageGroup' => 'api/company/APIWageGroup.class.php',
    'APICompanyDeduction' => 'api/company/APICompanyDeduction.class.php',
    'APIUserDeduction' => 'api/users/APIUserDeduction.class.php',
	'APICurrency' => 'api/core/APICurrency.class.php',
	'APIFactory' => 'api/core/APIFactory.class.php',
	'APIPermission' => 'api/core/APIPermission.class.php',
	'APIPermissionControl' => 'api/core/APIPermissionControl.class.php',
	'APIProgressBar' => 'api/core/APIProgressBar.class.php',
	'APIStation' => 'api/core/APIStation.class.php',
	'APITTDate' => 'api/core/APITTDate.class.php',
    'APIUserDateTotal' => 'api/core/APIUserDateTotal.class.php',
	'APIException' => 'api/core/APIException.class.php',
    'APITest' => 'api/core/APITest.class.php',
    'APINotification' => 'api/core/APINotification.class.php',
	'APIDepartment' => 'api/department/APIDepartment.class.php',
	'APIRecurringHoliday' => 'api/holiday/APIRecurringHoliday.class.php',
	'APIPayStubEntryAccount' => 'api/pay_stub/APIPayStubEntryAccount.class.php',
	'APIPayPeriod' => 'api/payperiod/APIPayPeriod.class.php',
    'APIPayPeriodTimeSheetVerify' => 'api/payperiod/APIPayPeriodTimeSheetVerify.class.php',
	'APIPayPeriodSchedule' => 'api/payperiod/APIPayPeriodSchedule.class.php',
	'APIAbsencePolicy' => 'api/policy/APIAbsencePolicy.class.php',
    'APIAccrualBalance' => 'api/accrual/APIAccrualBalance.class.php',
    'APIAccrual' => 'api/accrual/APIAccrual.class.php',
	'APIAccrualPolicy' => 'api/policy/APIAccrualPolicy.class.php',
	'APIAccrualPolicyMilestone' => 'api/policy/APIAccrualPolicyMilestone.class.php',
	'APIBreakPolicy' => 'api/policy/APIBreakPolicy.class.php',
	'APIExceptionPolicy' => 'api/policy/APIExceptionPolicy.class.php',
	'APIExceptionPolicyControl' => 'api/policy/APIExceptionPolicyControl.class.php',
	'APIHolidayPolicy' => 'api/policy/APIHolidayPolicy.class.php',
    'APIHoliday' => 'api/holiday/APIHoliday.class.php',
	'APIMealPolicy' => 'api/policy/APIMealPolicy.class.php',
	'APIOverTimePolicy' => 'api/policy/APIOverTimePolicy.class.php',
	'APIPolicyGroup' => 'api/policy/APIPolicyGroup.class.php',
	'APIPremiumPolicy' => 'api/policy/APIPremiumPolicy.class.php',
	'APIRoundIntervalPolicy' => 'api/policy/APIRoundIntervalPolicy.class.php',
	'APISchedulePolicy' => 'api/policy/APISchedulePolicy.class.php',
	'APIPunch' => 'api/punch/APIPunch.class.php',
    'APIPunchControl' => 'api/punch/APIPunchControl.class.php',
    'APITimeSheet' => 'api/core/APITimeSheet.class.php',
	'APISchedule' => 'api/schedule/APISchedule.class.php',
    'APIRecurringScheduleTemplateControl' => 'api/schedule/APIRecurringScheduleTemplateControl.class.php',
    'APIRecurringScheduleTemplate' => 'api/schedule/APIRecurringScheduleTemplate.class.php',
    'APIRecurringScheduleControl' => 'api/schedule/APIRecurringScheduleControl.class.php',
	'APIAuthentication' => 'api/unauthenticated/APIAuthentication.class.php',
    'APIAuthorization' => 'api/core/APIAuthorization.class.php',
	'APIUser' => 'api/users/APIUser.class.php',
	'APIUserReportData' => 'api/users/APIUserReportData.class.php',
	'APIUserGenericData' => 'api/users/APIUserGenericData.class.php',
	'APIUserGroup' => 'api/users/APIUserGroup.class.php',
	'APIUserPreference' => 'api/users/APIUserPreference.class.php',
    'APIUserDefault' => 'api/users/APIUserDefault.class.php',
	'APIUserTitle' => 'api/users/APIUserTitle.class.php',
	'APIUserWage' => 'api/users/APIUserWage.class.php',
    'APIJob' => 'api/job/APIJob.class.php',
    'APIJobGroup' => 'api/job/APIJobGroup.class.php',
    'APIJobItem' => 'api/job_item/APIJobItem.class.php',
    'APIJobItemGroup' => 'api/job_item/APIJobItemGroup.class.php',
    'APIPayStubAmendment' => 'api/pay_stub_amendment/APIPayStubAmendment.class.php',
    'APIRecurringPayStubAmendment' => 'api/pay_stub_amendment/APIRecurringPayStubAmendment.class.php',
    'APIHierarchyControl' => 'api/hierarchy/APIHierarchyControl.class.php',
    'APIHierarchyLevel' => 'api/hierarchy/APIHierarchyLevel.class.php',
    'APIPayStub' => 'api/pay_stub/APIPayStub.class.php',
    'APIMessageControl' => 'api/message/APIMessageControl.class.php',
    'APIClientGroup' => 'api/client/APIClientGroup.class.php',
    'APIProductGroup' => 'api/product/APIProductGroup.class.php',
    'APIDocumentGroup' => 'api/document/APIDocumentGroup.class.php',
    'APIClient' => 'api/client/APIClient.class.php',
    'APIClientContact' => 'api/client/APIClientContact.class.php',
    'APIClientPayment' => 'api/client/APIClientPayment.class.php',
    'APIRequest' => 'api/request/APIRequest.class.php',
    'APIDocument' => 'api/document/APIDocument.class.php',
    'APIDocumentRevision' => 'api/document/APIDocumentRevision.class.php',
    'APIDocumentAttachment' => 'api/document/APIDocumentAttachment.class.php',
    'APIReport' => 'api/report/APIReport.class.php',
    'APIReportSchedule' => 'api/report/APIReportSchedule.class.php',
    'APIUserSummaryReport' => 'api/report/APIUserSummaryReport.class.php',
    'APIActiveShiftReport' => 'api/report/APIActiveShiftReport.class.php',
    'APITimesheetSummaryReport' => 'api/report/APITimesheetSummaryReport.class.php',
    'APITimesheetDetailReport' => 'api/report/APITimesheetDetailReport.class.php',
    'APIPunchSummaryReport' => 'api/report/APIPunchSummaryReport.class.php',
    'APIPayStubSummaryReport' => 'api/report/APIPayStubSummaryReport.class.php',
    'APIScheduleSummaryReport' => 'api/report/APIScheduleSummaryReport.class.php',
    'APIInvoiceTransactionSummaryReport' => 'api/report/APIInvoiceTransactionSummaryReport.class.php',
    'APIPayrollExportReport' => 'api/report/APIPayrollExportReport.class.php',
    'APIForm941Report' => 'api/report/APIForm941Report.class.php',
    'APIForm940Report' => 'api/report/APIForm940Report.class.php',
    'APIFormW2Report' => 'api/report/APIFormW2Report.class.php',
    'APIForm1099MiscReport' => 'api/report/APIForm1099MiscReport.class.php',
    'APIRemittanceSummaryReport' => 'api/report/APIRemittanceSummaryReport.class.php',
    'APIT4SummaryReport' => 'api/report/APIT4SummaryReport.class.php',
    'APIJobDetailReport' => 'api/report/APIJobDetailReport.class.php',
    'APIJobSummaryReport' => 'api/report/APIJobSummaryReport.class.php',
    'APITimeClockUnAuthenticated' => 'api/time_clock/APITimeClockUnAuthenticated.class.php',
    'APITimeClockUnAuthenticated_TTA8' => 'api/time_clock/APITimeClockUnAuthenticated_TTA8.class.php',
    'APITimeClockUnAuthenticated_TTUS100' => 'api/time_clock/APITimeClockUnAuthenticated_TTUS100.class.php',
    'APIInvoiceDistrict' => 'api/invoice/APIInvoiceDistrict.class.php',
    'APIInvoice' => 'api/invoice/APIInvoice.class.php',
    'APITransaction' => 'api/invoice/APITransaction.class.php',
    'APIAreaPolicy' => 'api/invoice_policy/APIAreaPolicy.class.php',
    'APITaxPolicy' => 'api/invoice_policy/APITaxPolicy.class.php',
    'APIShippingPolicy' => 'api/invoice_policy/APIShippingPolicy.class.php',
    'APIProduct' => 'api/product/APIProduct.class.php',
    'APIProductPrice' => 'api/product/APIProductPrice.class.php',
    'APIImport' => 'api/import/APIImport.class.php',
    'APIImportUser' => 'api/import/APIImportUser.class.php',
    'APIImportBranch' => 'api/import/APIImportBranch.class.php',
    'APIImportDepartment' => 'api/import/APIImportDepartment.class.php',
    'APIImportUserWage' => 'api/import/APIImportUserWage.class.php',
    'APIImportClient' => 'api/import/APIImportClient.class.php',
	'ClientAuthentication' => 'client/ClientAuthentication.class.php',
	'ClientBalanceFactory' => 'client/ClientBalanceFactory.class.php',
	'ClientBalanceListFactory' => 'client/ClientBalanceListFactory.class.php',
	'ClientContactFactory' => 'client/ClientContactFactory.class.php',
	'ClientContactListFactory' => 'client/ClientContactListFactory.class.php',
	'ClientFactory' => 'client/ClientFactory.class.php',
	'ClientGroupFactory' => 'client/ClientGroupFactory.class.php',
	'ClientGroupListFactory' => 'client/ClientGroupListFactory.class.php',
	'ClientListFactory' => 'client/ClientListFactory.class.php',
	'ClientPaymentFactory' => 'client/ClientPaymentFactory.class.php',
	'ClientPaymentListFactory' => 'client/ClientPaymentListFactory.class.php',
	'BranchFactory' => 'company/BranchFactory.class.php',
	'BranchListFactory' => 'company/BranchListFactory.class.php',
	'CompanyDeductionFactory' => 'company/CompanyDeductionFactory.class.php',
	'CompanyDeductionListFactory' => 'company/CompanyDeductionListFactory.class.php',
	'CompanyDeductionPayStubEntryAccountFactory' => 'company/CompanyDeductionPayStubEntryAccountFactory.class.php',
	'CompanyDeductionPayStubEntryAccountListFactory' => 'company/CompanyDeductionPayStubEntryAccountListFactory.class.php',
	'CompanyFactory' => 'company/CompanyFactory.class.php',
	'CompanyGenericMapFactory' => 'company/CompanyGenericMapFactory.class.php',
	'CompanyGenericMapListFactory' => 'company/CompanyGenericMapListFactory.class.php',
	'CompanyGenericTagFactory' => 'company/CompanyGenericTagFactory.class.php',
	'CompanyGenericTagListFactory' => 'company/CompanyGenericTagListFactory.class.php',
	'CompanyGenericTagMapFactory' => 'company/CompanyGenericTagMapFactory.class.php',
	'CompanyGenericTagMapListFactory' => 'company/CompanyGenericTagMapListFactory.class.php',
	'CompanyListFactory' => 'company/CompanyListFactory.class.php',
	'CompanyUserCountFactory' => 'company/CompanyUserCountFactory.class.php',
	'CompanyUserCountListFactory' => 'company/CompanyUserCountListFactory.class.php',
	'WageGroupFactory' => 'company/WageGroupFactory.class.php',
	'WageGroupListFactory' => 'company/WageGroupListFactory.class.php',
	'AJAX_Server' => 'core/AJAX_Server.class.php',
	'Authentication' => 'core/Authentication.class.php',
	'AuthorizationFactory' => 'core/AuthorizationFactory.class.php',
	'AuthorizationListFactory' => 'core/AuthorizationListFactory.class.php',
	'BackgroundProcess' => 'core/BackgroundProcess.class.php',
	'BreadCrumb' => 'core/BreadCrumb.class.php',
	'CalculatePayStub' => 'core/CalculatePayStub.class.php',
	'CurrencyFactory' => 'core/CurrencyFactory.class.php',
	'CurrencyListFactory' => 'core/CurrencyListFactory.class.php',
	'Debug' => 'core/Debug.class.php',
    'RateLimit' => 'core/RateLimit.class.php',
	'DependencyTree' => 'core/DependencyTree.class.php',
	'Environment' => 'core/Environment.class.php',
	'Exception' => 'core/Exception.class.php',
	'ExceptionFactory' => 'core/ExceptionFactory.class.php',
	'ExceptionListFactory' => 'core/ExceptionListFactory.class.php',
	'Factory' => 'core/Factory.class.php',
	'FactoryListIterator' => 'core/FactoryListIterator.class.php',
	'FastTree' => 'core/FastTree.class.php',
	'FormVariables' => 'core/FormVariables.class.php',
	'GeneralLedgerExport' => 'core/GeneralLedgerExport.class.php',
	'LockFile' => 'core/LockFile.class.php',
	'LogFactory' => 'core/LogFactory.class.php',
	'LogListFactory' => 'core/LogListFactory.class.php',
    'LogDetailFactory' => 'core/LogDetailFactory.class.php',
    'LogDetailListFactory' => 'core/LogDetailListFactory.class.php',
    'LogDetailDisplay' => 'core/LogDetailDisplay.class.php',
	'LogRotate' => 'core/LogRotate.class.php',
	'Misc' => 'core/Misc.class.php',
	'Option' => 'core/Option.class.php',
    'TTLDAP' => 'core/TTLDAP.class.php',
	'OtherFieldFactory' => 'core/OtherFieldFactory.class.php',
	'OtherFieldListFactory' => 'core/OtherFieldListFactory.class.php',
	'Pager' => 'core/Pager.class.php',
	'Permission' => 'core/Permission.class.php',
	'PermissionControlFactory' => 'core/PermissionControlFactory.class.php',
	'PermissionControlListFactory' => 'core/PermissionControlListFactory.class.php',
	'PermissionFactory' => 'core/PermissionFactory.class.php',
	'PermissionListFactory' => 'core/PermissionListFactory.class.php',
	'PermissionUserFactory' => 'core/PermissionUserFactory.class.php',
	'PermissionUserListFactory' => 'core/PermissionUserListFactory.class.php',
    'PurgeDatabase' => 'core/PurgeDatabase.class.php',
	'Profiler' => 'core/Profiler.class.php',
	'ProgressBar' => 'core/ProgressBar.class.php',
	'Redirect' => 'core/Redirect.class.php',
	'Serializer' => 'core/Serializer.class.php',
	'SharedMemory' => 'core/SharedMemory.class.php',
	'Sort' => 'core/Sort.class.php',
    'Group' => 'core/Group.class.php',
    'Report' => 'report/Report.class.php',
    'ReportChart' => 'report/ReportChart.class.php',
    'ReportScheduleFactory' => 'report/ReportScheduleFactory.class.php',
    'ReportScheduleListFactory' => 'report/ReportScheduleListFactory.class.php',
    'UserSummaryReport' => 'report/UserSummaryReport.class.php',
    'ActiveShiftReport' => 'report/ActiveShiftReport.class.php',
    'TimesheetSummaryReport' => 'report/TimesheetSummaryReport.class.php',
    'TimesheetDetailReport' => 'report/TimesheetDetailReport.class.php',
    'PunchSummaryReport' => 'report/PunchSummaryReport.class.php',
    'ScheduleSummaryReport' => 'report/ScheduleSummaryReport.class.php',
    'PayStubSummaryReport' => 'report/PayStubSummaryReport.class.php',
    'InvoiceTransactionSummaryReport' => 'report/InvoiceTransactionSummaryReport.class.php',
    'PayrollExportReport' => 'report/PayrollExportReport.class.php',
    'Form941Report' => 'report/Form941Report.class.php',
    'Form940Report' => 'report/Form940Report.class.php',
    'FormW2Report' => 'report/FormW2Report.class.php',
    'Form1099MiscReport' => 'report/Form1099MiscReport.class.php',
    'RemittanceSummaryReport' => 'report/RemittanceSummaryReport.class.php',
    'T4SummaryReport' => 'report/T4SummaryReport.class.php',
    'JobDetailReport' => 'report/JobDetailReport.class.php',
    'JobSummaryReport' => 'report/JobSummaryReport.class.php',
	'StationBranchFactory' => 'core/StationBranchFactory.class.php',
	'StationBranchListFactory' => 'core/StationBranchListFactory.class.php',
	'StationDepartmentFactory' => 'core/StationDepartmentFactory.class.php',
	'StationDepartmentListFactory' => 'core/StationDepartmentListFactory.class.php',
	'StationExcludeUserFactory' => 'core/StationExcludeUserFactory.class.php',
	'StationExcludeUserListFactory' => 'core/StationExcludeUserListFactory.class.php',
	'StationFactory' => 'core/StationFactory.class.php',
	'StationIncludeUserFactory' => 'core/StationIncludeUserFactory.class.php',
	'StationIncludeUserListFactory' => 'core/StationIncludeUserListFactory.class.php',
	'StationListFactory' => 'core/StationListFactory.class.php',
	'StationUserFactory' => 'core/StationUserFactory.class.php',
	'StationUserGroupFactory' => 'core/StationUserGroupFactory.class.php',
	'StationUserGroupListFactory' => 'core/StationUserGroupListFactory.class.php',
	'StationUserListFactory' => 'core/StationUserListFactory.class.php',
	'SystemSettingFactory' => 'core/SystemSettingFactory.class.php',
	'SystemSettingListFactory' => 'core/SystemSettingListFactory.class.php',
	'TTDate' => 'core/TTDate.class.php',
	'TTLicense' => 'core/TTLicense.class.php',
	'TTLicense.private' => 'core/TTLicense.private.class.php',
	'TTLicenseGenerator' => 'core/TTLicenseGenerator.class.php',
	'TTLog' => 'core/TTLog.class.php',
	'TTMail' => 'core/TTMail.class.php',
	'TTPDF' => 'core/TTPDF.class.php',
	'TTi18n' => 'core/TTi18n.class.php',
	'URLBuilder' => 'core/URLBuilder.class.php',
	'UnitConvert' => 'core/UnitConvert.class.php',
	'UserDateFactory' => 'core/UserDateFactory.class.php',
	'UserDateListFactory' => 'core/UserDateListFactory.class.php',
	'UserDateTotalFactory' => 'core/UserDateTotalFactory.class.php',
	'UserDateTotalListFactory' => 'core/UserDateTotalListFactory.class.php',
	'Validator' => 'core/Validator.class.php',
	'Wage' => 'core/Wage.class.php',
    'Cron' => 'cron/Cron.class.php',
	'CronJobFactory' => 'cron/CronJobFactory.class.php',
	'CronJobListFactory' => 'cron/CronJobListFactory.class.php',
	'DepartmentBranchFactory' => 'department/DepartmentBranchFactory.class.php',
	'DepartmentBranchListFactory' => 'department/DepartmentBranchListFactory.class.php',
	'DepartmentBranchUserFactory' => 'department/DepartmentBranchUserFactory.class.php',
	'DepartmentBranchUserListFactory' => 'department/DepartmentBranchUserListFactory.class.php',
	'DepartmentFactory' => 'department/DepartmentFactory.class.php',
	'DepartmentListFactory' => 'department/DepartmentListFactory.class.php',
	'DocumentAttachmentFactory' => 'document/DocumentAttachmentFactory.class.php',
	'DocumentAttachmentListFactory' => 'document/DocumentAttachmentListFactory.class.php',
	'DocumentFactory' => 'document/DocumentFactory.class.php',
	'DocumentGroupFactory' => 'document/DocumentGroupFactory.class.php',
	'DocumentGroupListFactory' => 'document/DocumentGroupListFactory.class.php',
	'DocumentListFactory' => 'document/DocumentListFactory.class.php',
	'DocumentRevisionFactory' => 'document/DocumentRevisionFactory.class.php',
	'DocumentRevisionListFactory' => 'document/DocumentRevisionListFactory.class.php',
	'HelpFactory' => 'help/HelpFactory.class.php',
	'HelpGroupControlFactory' => 'help/HelpGroupControlFactory.class.php',
	'HelpGroupControlListFactory' => 'help/HelpGroupControlListFactory.class.php',
	'HelpGroupFactory' => 'help/HelpGroupFactory.class.php',
	'HelpGroupListFactory' => 'help/HelpGroupListFactory.class.php',
	'HelpListFactory' => 'help/HelpListFactory.class.php',
	'HierarchyControlFactory' => 'hierarchy/HierarchyControlFactory.class.php',
	'HierarchyControlListFactory' => 'hierarchy/HierarchyControlListFactory.class.php',
	'HierarchyFactory' => 'hierarchy/HierarchyFactory.class.php',
	'HierarchyLevelFactory' => 'hierarchy/HierarchyLevelFactory.class.php',
	'HierarchyLevelListFactory' => 'hierarchy/HierarchyLevelListFactory.class.php',
	'HierarchyListFactory' => 'hierarchy/HierarchyListFactory.class.php',
	'HierarchyObjectTypeFactory' => 'hierarchy/HierarchyObjectTypeFactory.class.php',
	'HierarchyObjectTypeListFactory' => 'hierarchy/HierarchyObjectTypeListFactory.class.php',
	'HierarchyShareFactory' => 'hierarchy/HierarchyShareFactory.class.php',
	'HierarchyShareListFactory' => 'hierarchy/HierarchyShareListFactory.class.php',
	'HierarchyUserFactory' => 'hierarchy/HierarchyUserFactory.class.php',
	'HierarchyUserListFactory' => 'hierarchy/HierarchyUserListFactory.class.php',
	'HolidayFactory' => 'holiday/HolidayFactory.class.php',
	'HolidayListFactory' => 'holiday/HolidayListFactory.class.php',
	'RecurringHolidayFactory' => 'holiday/RecurringHolidayFactory.class.php',
	'RecurringHolidayListFactory' => 'holiday/RecurringHolidayListFactory.class.php',
	'Install' => 'install/Install.class.php',
	'InstallSchema' => 'install/InstallSchema.class.php',
	'InstallSchema_Base' => 'install/InstallSchema_Base.class.php',
	'InvoiceConfigFactory' => 'invoice/InvoiceConfigFactory.class.php',
	'InvoiceConfigListFactory' => 'invoice/InvoiceConfigListFactory.class.php',
	'InvoiceDistrictFactory' => 'invoice/InvoiceDistrictFactory.class.php',
	'InvoiceDistrictListFactory' => 'invoice/InvoiceDistrictListFactory.class.php',
	'InvoiceFactory' => 'invoice/InvoiceFactory.class.php',
	'InvoiceListFactory' => 'invoice/InvoiceListFactory.class.php',
	'PaymentGatewayCreditCardTypeFactory' => 'invoice/PaymentGatewayCreditCardTypeFactory.class.php',
	'PaymentGatewayCreditCardTypeListFactory' => 'invoice/PaymentGatewayCreditCardTypeListFactory.class.php',
	'PaymentGatewayCurrencyFactory' => 'invoice/PaymentGatewayCurrencyFactory.class.php',
	'PaymentGatewayCurrencyListFactory' => 'invoice/PaymentGatewayCurrencyListFactory.class.php',
	'PaymentGatewayFactory' => 'invoice/PaymentGatewayFactory.class.php',
	'PaymentGatewayListFactory' => 'invoice/PaymentGatewayListFactory.class.php',
	'TransactionFactory' => 'invoice/TransactionFactory.class.php',
	'TransactionListFactory' => 'invoice/TransactionListFactory.class.php',
	'AreaPolicyFactory' => 'invoice_policy/AreaPolicyFactory.class.php',
	'AreaPolicyListFactory' => 'invoice_policy/AreaPolicyListFactory.class.php',
	'AreaPolicyLocationFactory' => 'invoice_policy/AreaPolicyLocationFactory.class.php',
	'AreaPolicyLocationListFactory' => 'invoice_policy/AreaPolicyLocationListFactory.class.php',
	'ShippingPolicyFactory' => 'invoice_policy/ShippingPolicyFactory.class.php',
	'ShippingPolicyListFactory' => 'invoice_policy/ShippingPolicyListFactory.class.php',
	'ShippingPolicyObjectFactory' => 'invoice_policy/ShippingPolicyObjectFactory.class.php',
	'ShippingPolicyObjectListFactory' => 'invoice_policy/ShippingPolicyObjectListFactory.class.php',
	'TaxPolicyFactory' => 'invoice_policy/TaxPolicyFactory.class.php',
	'TaxPolicyListFactory' => 'invoice_policy/TaxPolicyListFactory.class.php',
	'TaxPolicyObjectFactory' => 'invoice_policy/TaxPolicyObjectFactory.class.php',
	'TaxPolicyObjectListFactory' => 'invoice_policy/TaxPolicyObjectListFactory.class.php',
	'JobFactory' => 'job/JobFactory.class.php',
	'JobGroupFactory' => 'job/JobGroupFactory.class.php',
	'JobGroupListFactory' => 'job/JobGroupListFactory.class.php',
	'JobListFactory' => 'job/JobListFactory.class.php',
	'JobReport' => 'job/JobReport.class.php',
	'JobUserAllowFactory' => 'job/JobUserAllowFactory.class.php',
	'JobUserAllowListFactory' => 'job/JobUserAllowListFactory.class.php',
	'JobItemAllowFactory' => 'job_item/JobItemAllowFactory.class.php',
	'JobItemAllowListFactory' => 'job_item/JobItemAllowListFactory.class.php',
	'JobItemAmendmentFactory' => 'job_item/JobItemAmendmentFactory.class.php',
	'JobItemAmendmentListFactory' => 'job_item/JobItemAmendmentListFactory.class.php',
	'JobItemFactory' => 'job_item/JobItemFactory.class.php',
	'JobItemGroupFactory' => 'job_item/JobItemGroupFactory.class.php',
	'JobItemGroupListFactory' => 'job_item/JobItemGroupListFactory.class.php',
	'JobItemListFactory' => 'job_item/JobItemListFactory.class.php',
    'MessageControlFactory' => 'message/MessageControlFactory.class.php',
    'MessageControlListFactory' => 'message/MessageControlListFactory.class.php',
    'MessageRecipientFactory' => 'message/MessageRecipientFactory.class.php',
    'MessageRecipientListFactory' => 'message/MessageRecipientListFactory.class.php',
    'MessageSenderFactory' => 'message/MessageSenderFactory.class.php',
    'MessageSenderListFactory' => 'message/MessageSenderListFactory.class.php',
	'MessageFactory' => 'message/MessageFactory.class.php',
	'MessageListFactory' => 'message/MessageListFactory.class.php',
	'DemoData' => 'other/DemoData.class.php',
	'EFT' => 'other/EFT.class.php',
	'IncomeTaxCompare' => 'other/IncomeTaxCompare.class.php',
	'ROEFactory' => 'other/ROEFactory.class.php',
	'ROEListFactory' => 'other/ROEListFactory.class.php',
	'Telnet' => 'other/Telnet.class.php',
	'PayStub' => 'pay_stub/PayStub.class.php',
	'PayStubEntryAccountFactory' => 'pay_stub/PayStubEntryAccountFactory.class.php',
	'PayStubEntryAccountLinkFactory' => 'pay_stub/PayStubEntryAccountLinkFactory.class.php',
	'PayStubEntryAccountLinkListFactory' => 'pay_stub/PayStubEntryAccountLinkListFactory.class.php',
	'PayStubEntryAccountListFactory' => 'pay_stub/PayStubEntryAccountListFactory.class.php',
	'PayStubEntryFactory' => 'pay_stub/PayStubEntryFactory.class.php',
	'PayStubEntryListFactory' => 'pay_stub/PayStubEntryListFactory.class.php',
	'PayStubFactory' => 'pay_stub/PayStubFactory.class.php',
	'PayStubListFactory' => 'pay_stub/PayStubListFactory.class.php',
	'PayStubPDF' => 'pay_stub/PayStubPDF.class.php',
	'PayStubAmendmentFactory' => 'pay_stub_amendment/PayStubAmendmentFactory.class.php',
	'PayStubAmendmentListFactory' => 'pay_stub_amendment/PayStubAmendmentListFactory.class.php',
	'RecurringPayStubAmendmentFactory' => 'pay_stub_amendment/RecurringPayStubAmendmentFactory.class.php',
	'RecurringPayStubAmendmentListFactory' => 'pay_stub_amendment/RecurringPayStubAmendmentListFactory.class.php',
	'RecurringPayStubAmendmentUserFactory' => 'pay_stub_amendment/RecurringPayStubAmendmentUserFactory.class.php',
	'RecurringPayStubAmendmentUserListFactory' => 'pay_stub_amendment/RecurringPayStubAmendmentUserListFactory.class.php',
	'PayPeriodFactory' => 'payperiod/PayPeriodFactory.class.php',
	'PayPeriodListFactory' => 'payperiod/PayPeriodListFactory.class.php',
	'PayPeriodScheduleFactory' => 'payperiod/PayPeriodScheduleFactory.class.php',
	'PayPeriodScheduleListFactory' => 'payperiod/PayPeriodScheduleListFactory.class.php',
	'PayPeriodScheduleUserFactory' => 'payperiod/PayPeriodScheduleUserFactory.class.php',
	'PayPeriodScheduleUserListFactory' => 'payperiod/PayPeriodScheduleUserListFactory.class.php',
	'PayPeriodTimeSheetVerifyFactory' => 'payperiod/PayPeriodTimeSheetVerifyFactory.class.php',
	'PayPeriodTimeSheetVerifyListFactory' => 'payperiod/PayPeriodTimeSheetVerifyListFactory.class.php',
	'AbsencePolicyFactory' => 'policy/AbsencePolicyFactory.class.php',
	'AbsencePolicyListFactory' => 'policy/AbsencePolicyListFactory.class.php',
	'AccrualPolicyFactory' => 'policy/AccrualPolicyFactory.class.php',
	'AccrualPolicyListFactory' => 'policy/AccrualPolicyListFactory.class.php',
	'AccrualPolicyMilestoneFactory' => 'policy/AccrualPolicyMilestoneFactory.class.php',
	'AccrualPolicyMilestoneListFactory' => 'policy/AccrualPolicyMilestoneListFactory.class.php',
	'BreakPolicyFactory' => 'policy/BreakPolicyFactory.class.php',
	'BreakPolicyListFactory' => 'policy/BreakPolicyListFactory.class.php',
	'ExceptionPolicyControlFactory' => 'policy/ExceptionPolicyControlFactory.class.php',
	'ExceptionPolicyControlListFactory' => 'policy/ExceptionPolicyControlListFactory.class.php',
	'ExceptionPolicyFactory' => 'policy/ExceptionPolicyFactory.class.php',
	'ExceptionPolicyListFactory' => 'policy/ExceptionPolicyListFactory.class.php',
	'HolidayPolicyFactory' => 'policy/HolidayPolicyFactory.class.php',
	'HolidayPolicyListFactory' => 'policy/HolidayPolicyListFactory.class.php',
	'HolidayPolicyRecurringHolidayFactory' => 'policy/HolidayPolicyRecurringHolidayFactory.class.php',
	'HolidayPolicyRecurringHolidayListFactory' => 'policy/HolidayPolicyRecurringHolidayListFactory.class.php',
	'MealPolicyFactory' => 'policy/MealPolicyFactory.class.php',
	'MealPolicyListFactory' => 'policy/MealPolicyListFactory.class.php',
	'OverTimePolicyFactory' => 'policy/OverTimePolicyFactory.class.php',
	'OverTimePolicyListFactory' => 'policy/OverTimePolicyListFactory.class.php',
	'PolicyGroupAccrualPolicyFactory' => 'policy/PolicyGroupAccrualPolicyFactory.class.php',
	'PolicyGroupAccrualPolicyListFactory' => 'policy/PolicyGroupAccrualPolicyListFactory.class.php',
	'PolicyGroupFactory' => 'policy/PolicyGroupFactory.class.php',
	'PolicyGroupListFactory' => 'policy/PolicyGroupListFactory.class.php',
	'PolicyGroupOverTimePolicyFactory' => 'policy/PolicyGroupOverTimePolicyFactory.class.php',
	'PolicyGroupOverTimePolicyListFactory' => 'policy/PolicyGroupOverTimePolicyListFactory.class.php',
	'PolicyGroupPremiumPolicyFactory' => 'policy/PolicyGroupPremiumPolicyFactory.class.php',
	'PolicyGroupPremiumPolicyListFactory' => 'policy/PolicyGroupPremiumPolicyListFactory.class.php',
	'PolicyGroupRoundIntervalPolicyFactory' => 'policy/PolicyGroupRoundIntervalPolicyFactory.class.php',
	'PolicyGroupRoundIntervalPolicyListFactory' => 'policy/PolicyGroupRoundIntervalPolicyListFactory.class.php',
	'PolicyGroupUserFactory' => 'policy/PolicyGroupUserFactory.class.php',
	'PolicyGroupUserListFactory' => 'policy/PolicyGroupUserListFactory.class.php',
	'PremiumPolicyBranchFactory' => 'policy/PremiumPolicyBranchFactory.class.php',
	'PremiumPolicyBranchListFactory' => 'policy/PremiumPolicyBranchListFactory.class.php',
	'PremiumPolicyDepartmentFactory' => 'policy/PremiumPolicyDepartmentFactory.class.php',
	'PremiumPolicyDepartmentListFactory' => 'policy/PremiumPolicyDepartmentListFactory.class.php',
	'PremiumPolicyFactory' => 'policy/PremiumPolicyFactory.class.php',
	'PremiumPolicyJobFactory' => 'policy/PremiumPolicyJobFactory.class.php',
	'PremiumPolicyJobGroupFactory' => 'policy/PremiumPolicyJobGroupFactory.class.php',
	'PremiumPolicyJobGroupListFactory' => 'policy/PremiumPolicyJobGroupListFactory.class.php',
	'PremiumPolicyJobItemFactory' => 'policy/PremiumPolicyJobItemFactory.class.php',
	'PremiumPolicyJobItemGroupFactory' => 'policy/PremiumPolicyJobItemGroupFactory.class.php',
	'PremiumPolicyJobItemGroupListFactory' => 'policy/PremiumPolicyJobItemGroupListFactory.class.php',
	'PremiumPolicyJobItemListFactory' => 'policy/PremiumPolicyJobItemListFactory.class.php',
	'PremiumPolicyJobListFactory' => 'policy/PremiumPolicyJobListFactory.class.php',
	'PremiumPolicyListFactory' => 'policy/PremiumPolicyListFactory.class.php',
	'RoundIntervalPolicyFactory' => 'policy/RoundIntervalPolicyFactory.class.php',
	'RoundIntervalPolicyListFactory' => 'policy/RoundIntervalPolicyListFactory.class.php',
	'SchedulePolicyFactory' => 'policy/SchedulePolicyFactory.class.php',
	'SchedulePolicyListFactory' => 'policy/SchedulePolicyListFactory.class.php',
	'ProductFactory' => 'product/ProductFactory.class.php',
	'ProductGroupFactory' => 'product/ProductGroupFactory.class.php',
	'ProductGroupListFactory' => 'product/ProductGroupListFactory.class.php',
	'ProductListFactory' => 'product/ProductListFactory.class.php',
	'ProductPriceFactory' => 'product/ProductPriceFactory.class.php',
	'ProductPriceListFactory' => 'product/ProductPriceListFactory.class.php',
	'ProductTaxPolicyProductFactory' => 'product/ProductTaxPolicyProductFactory.class.php',
	'ProductTaxPolicyProductListFactory' => 'product/ProductTaxPolicyProductListFactory.class.php',
	'PunchControlFactory' => 'punch/PunchControlFactory.class.php',
	'PunchControlListFactory' => 'punch/PunchControlListFactory.class.php',
	'PunchFactory' => 'punch/PunchFactory.class.php',
	'PunchListFactory' => 'punch/PunchListFactory.class.php',
	'RequestFactory' => 'request/RequestFactory.class.php',
	'RequestListFactory' => 'request/RequestListFactory.class.php',
	'RecurringScheduleControlFactory' => 'schedule/RecurringScheduleControlFactory.class.php',
	'RecurringScheduleControlListFactory' => 'schedule/RecurringScheduleControlListFactory.class.php',
	'RecurringScheduleTemplateControlFactory' => 'schedule/RecurringScheduleTemplateControlFactory.class.php',
	'RecurringScheduleTemplateControlListFactory' => 'schedule/RecurringScheduleTemplateControlListFactory.class.php',
	'RecurringScheduleTemplateFactory' => 'schedule/RecurringScheduleTemplateFactory.class.php',
	'RecurringScheduleTemplateListFactory' => 'schedule/RecurringScheduleTemplateListFactory.class.php',
	'RecurringScheduleUserFactory' => 'schedule/RecurringScheduleUserFactory.class.php',
	'RecurringScheduleUserListFactory' => 'schedule/RecurringScheduleUserListFactory.class.php',
	'ScheduleFactory' => 'schedule/ScheduleFactory.class.php',
	'ScheduleListFactory' => 'schedule/ScheduleListFactory.class.php',
	'SoapClientTimeout' => 'soap/SoapClientTimeout.class.php',
	'TimeTrexSoapClient' => 'soap/TimeTrexSoapClient.class.php',
	'TimeTrexSoapServer' => 'soap/TimeTrexSoapServer.class.php',
	'TimeTrexSoapServerUnAuthenticated' => 'soap/TimeTrexSoapServerUnAuthenticated.class.php',
	'TaxForms' => 'tax_forms/TaxForms.class.php',
	'T4' => 'tax_forms/ca/T4.class.php',
	'TimeClock' => 'time_clock/TimeClock.class.php',
	'TimeClock_ACTAtek' => 'time_clock/TimeClock_ACTAtek.class.php',
	'TimeClock_Base' => 'time_clock/TimeClock_Base.class.php',
	'TimeClock_TTA8' => 'time_clock/TimeClock_TTA8.class.php',
	'TimeClock_TTF4' => 'time_clock/TimeClock_TTF4.class.php',
	'TimeClock_TTS300' => 'time_clock/TimeClock_TTS300.class.php',
	'BankAccountFactory' => 'users/BankAccountFactory.class.php',
	'BankAccountListFactory' => 'users/BankAccountListFactory.class.php',
	'UserDeductionFactory' => 'users/UserDeductionFactory.class.php',
	'UserDeductionListFactory' => 'users/UserDeductionListFactory.class.php',
	'UserDefaultCompanyDeductionFactory' => 'users/UserDefaultCompanyDeductionFactory.class.php',
	'UserDefaultCompanyDeductionListFactory' => 'users/UserDefaultCompanyDeductionListFactory.class.php',
	'UserDefaultFactory' => 'users/UserDefaultFactory.class.php',
	'UserDefaultListFactory' => 'users/UserDefaultListFactory.class.php',
	'UserFactory' => 'users/UserFactory.class.php',
	'UserGenericDataFactory' => 'users/UserGenericDataFactory.class.php',
	'UserGenericDataListFactory' => 'users/UserGenericDataListFactory.class.php',
	'UserGenericStatusFactory' => 'users/UserGenericStatusFactory.class.php',
	'UserGenericStatusListFactory' => 'users/UserGenericStatusListFactory.class.php',
	'UserReportDataFactory' => 'users/UserReportDataFactory.class.php',
	'UserReportDataListFactory' => 'users/UserReportDataListFactory.class.php',
	'UserGroupFactory' => 'users/UserGroupFactory.class.php',
	'UserGroupListFactory' => 'users/UserGroupListFactory.class.php',
	'UserIdentificationFactory' => 'users/UserIdentificationFactory.class.php',
	'UserIdentificationListFactory' => 'users/UserIdentificationListFactory.class.php',
	'UserListFactory' => 'users/UserListFactory.class.php',
	'UserPreferenceFactory' => 'users/UserPreferenceFactory.class.php',
	'UserPreferenceListFactory' => 'users/UserPreferenceListFactory.class.php',
	'UserTitleFactory' => 'users/UserTitleFactory.class.php',
	'UserTitleListFactory' => 'users/UserTitleListFactory.class.php',
	'UserWageFactory' => 'users/UserWageFactory.class.php',
	'UserWageListFactory' => 'users/UserWageListFactory.class.php',
    'Import' => 'import/Import.class.php',
    'ImportUser' => 'import/ImportUser.class.php',
    'ImportBranch' => 'import/ImportBranch.class.php',
    'ImportDepartment' => 'import/ImportDepartment.class.php',
    'ImportUserWage' => 'import/ImportUserWage.class.php',
    'ImportClient' => 'import/ImportClient.class.php',
);
?>
